# django-twc-toolbox

[![PyPI](https://img.shields.io/pypi/v/django-twc-toolbox)](https://pypi.org/project/django-twc-toolbox/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/django-twc-toolbox)
![Django Version](https://img.shields.io/badge/django-4.2%20%7C%205.0-%2344B78B?labelColor=%23092E20)
<!-- https://shields.io/badges -->
<!-- django-4.2 | 5.0-#44B78B -->
<!-- labelColor=%23092E20 -->

## Requirements

- Python 3.8, 3.9, 3.10, 3.11, 3.12
- Django 4.2, 5.0

## Getting Started

1. Install the package from PyPI:

```bash
python -m pip install django-twc-toolbox
```

2. Add the app to your Django project's `INSTALLED_APPS`:

```python
INSTALLED_APPS = [
    ...,
    "django_twc_toolbox",
    ...,
]
```

## Usage

## Documentation

Please refer to the [documentation](https://django-twc-toolbox.westervelt.dev/) for more information.

## License

`django-twc-toolbox` is licensed under the MIT license. See the [`LICENSE`](LICENSE) file for more information.
